rcmpy package — docs

Skip to main content
`Ctrl`+`K`

# rcmpy package

## Subpackages

- rcmpy.commands package
  - Submodules
  - rcmpy.commands.all module
    - `commands()`
  - rcmpy.commands.apply module
    - `add_apply_cmd()`
    - `apply_cmd()`
    - `apply_env()`
  - rcmpy.commands.common module
    - `add_default_flag()`
    - `run_env_command()`
  - rcmpy.commands.dump module
    - `add_dump_cmd()`
    - `dump_cmd()`
    - `dump_env()`
  - rcmpy.commands.use module
    - `add_use_cmd()`
    - `use_cmd()`
  - rcmpy.commands.variant module
    - `add_variant_cmd()`
    - `variant_cmd()`
  - rcmpy.commands.watch module
    - `add_watch_cmd()`
    - `watch_cmd()`
  - Module contents
- rcmpy.config package
  - Submodules
  - rcmpy.config.file module
    - `ManagedFile`
      - `ManagedFile.condition`
      - `ManagedFile.directory`
      - `ManagedFile.evaluate()`
      - `ManagedFile.executable`
      - `ManagedFile.extra_templates`
      - `ManagedFile.link`
      - `ManagedFile.name`
      - `ManagedFile.output`
      - `ManagedFile.platform`
      - `ManagedFile.platforms`
      - `ManagedFile.present`
      - `ManagedFile.template`
      - `ManagedFile.update()`
      - `ManagedFile.update_root()`
  - Module contents
    - `Config`
      - `Config.init()`
      - `Config.update_root()`
    - `ManagedFile`
      - `ManagedFile.condition`
      - `ManagedFile.directory`
      - `ManagedFile.evaluate()`
      - `ManagedFile.executable`
      - `ManagedFile.extra_templates`
      - `ManagedFile.link`
      - `ManagedFile.name`
      - `ManagedFile.output`
      - `ManagedFile.platform`
      - `ManagedFile.platforms`
      - `ManagedFile.present`
      - `ManagedFile.template`
      - `ManagedFile.update()`
      - `ManagedFile.update_root()`
- rcmpy.environment package
  - Submodules
  - rcmpy.environment.base module
    - `BaseEnvironment`
      - `BaseEnvironment.config`
      - `BaseEnvironment.config_loaded`
    - `load_if_single_candidate()`
    - `load_manifest()`
  - rcmpy.environment.data module
    - `system_data()`
  - rcmpy.environment.template module
    - `EnvTemplate`
      - `EnvTemplate.name`
      - `EnvTemplate.path`
      - `EnvTemplate.subdir`
      - `EnvTemplate.template`
    - `TemplateEnvironment`
      - `TemplateEnvironment.is_updated()`
      - `TemplateEnvironment.jinja`
      - `TemplateEnvironment.templates`
      - `TemplateEnvironment.templates_by_name`
    - `template_name()`
  - Module contents
    - `Environment`
    - `load_environment()`
- rcmpy.paths package
  - Module contents
    - `default_cache_directory()`
    - `default_config_directory()`
    - `default_state_directory()`
    - `override_environ()`
    - `override_environ_tempdir()`
- rcmpy.state package
  - Module contents
    - `State`
      - `State.asdict()`
      - `State.configs_new`
      - `State.directory`
      - `State.init()`
      - `State.is_new()`
      - `State.manifest`
      - `State.manifest_new`
      - `State.root_directories()`
      - `State.set_directory()`
      - `State.set_variant()`
      - `State.update_manifest()`
      - `State.variables_new`
      - `State.variant`
    - `load_state()`
- rcmpy.watch package
  - Submodules
  - rcmpy.watch.params module
    - `WatchParams`
      - `WatchParams.add_args()`
      - `WatchParams.base`
      - `WatchParams.check_contents`
      - `WatchParams.cmd`
      - `WatchParams.directory`
      - `WatchParams.from_args()`
      - `WatchParams.poll_rate`
      - `WatchParams.shell`
      - `WatchParams.single_pass`
  - Module contents
    - `command()`
    - `entry()`
    - `watch()`
    - `watch_cache()`
- rcmpy.xdg package
  - Module contents
    - `config_directories()`
    - `data_directories()`
    - `ensure_absolute()`
    - `iterate_directories()`
    - `root_directory()`
    - `user_bin()`
    - `user_cache()`
    - `user_config()`
    - `user_data()`
    - `user_state()`

## Submodules

## rcmpy.app module

This package’s command-line entry-point application.

rcmpy.app.add_app_args(parser: ArgumentParser) → None

  Add application-specific arguments to the command-line parser.

rcmpy.app.entry(args: Namespace) → int

  Execute the requested task.

## rcmpy.entry module

This package’s command-line entry-point (boilerplate).

rcmpy.entry.main(argv: list[str] = None) → int

  Program entry-point.

## rcmpy.schemas module

A module for working with schemas belonging to this package.

class rcmpy.schemas.RcmpyDictCodec(data: dict[str, str | int | float | bool | None | dict[str, str | int | float | bool | None] | list[str | int | float | bool | None]] = None, schemas: SchemaMap = None, dest_attr: str = 'data', verify: bool = True)

  Bases: `DictCodec`

  A simple wrapper for package classes that want to implement DictCodec.

  default_schemas: SchemaMap | None = {'State': <vcorelib.schemas.json.JsonSchema object>, 'ManagedFile': <vcorelib.schemas.json.JsonSchema object>, 'Config': <vcorelib.schemas.json.JsonSchema object>}

## Module contents

Useful defaults and other package metadata.